from setuptools import setup, find_packages


setup(
    name='dukaan-requests',
    version='0.1',
    author="",
    author_email='mehboob.shaik@mydukaan.io',
    url='https://github.com/teamdukaan',
    keywords='package'
)
